Welcome to mirror list, hosted at ThFree Co, Russian Federation.

gitlab.com/gitlab-org/gitaly.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorPaul Okstad <pokstad@gitlab.com>2019-08-06 20:02:15 +0300
committerJohn Cai <jcai@gitlab.com>2019-08-06 20:02:15 +0300
commitfe5149e5548966c1c93c1f820aa0e61e299ef961 (patch)
tree8be75adffad8245540b4fc2cfaaae63d4039ee8a
parent7f1e11018f45e578c9ae2692963617b0c401193d (diff)
Add gRPC method scope to protoregistry
-rw-r--r--changelogs/unreleased/po-method-info-scope.yml5
-rw-r--r--internal/praefect/protoregistry/protoregistry.go27
-rw-r--r--internal/praefect/protoregistry/protoregistry_test.go32
-rw-r--r--proto/README.md2
-rw-r--r--proto/REVISION2
-rw-r--r--proto/VERSION2
-rw-r--r--proto/go/gitalypb/namespace.pb.go42
-rw-r--r--proto/go/gitalypb/shared.pb.go123
-rw-r--r--proto/go/gitalypb/storage.pb.go36
-rw-r--r--proto/namespace.proto8
-rw-r--r--proto/shared.proto8
-rw-r--r--proto/storage.proto8
-rw-r--r--ruby/proto/gitaly/shared_pb.rb1
13 files changed, 183 insertions, 113 deletions
diff --git a/changelogs/unreleased/po-method-info-scope.yml b/changelogs/unreleased/po-method-info-scope.yml
new file mode 100644
index 000000000..c5da5c265
--- /dev/null
+++ b/changelogs/unreleased/po-method-info-scope.yml
@@ -0,0 +1,5 @@
+---
+title: Add gRPC method scope to protoregistry
+merge_request: 1397
+author:
+type: performance
diff --git a/internal/praefect/protoregistry/protoregistry.go b/internal/praefect/protoregistry/protoregistry.go
index 811b56140..28610ae8b 100644
--- a/internal/praefect/protoregistry/protoregistry.go
+++ b/internal/praefect/protoregistry/protoregistry.go
@@ -43,11 +43,32 @@ const (
OpMutator
)
+// Scope represents the intended scope of an RPC method
+type Scope int
+
+const (
+ // ScopeUnknown is the default scope until determined otherwise
+ ScopeUnknown = iota
+ // ScopeRepository indicates an RPC's scope is limited to a repository
+ ScopeRepository = iota
+ // ScopeStorage indicates an RPC is scoped to an entire storage location
+ ScopeStorage
+ // ScopeServer indicates an RPC is scoped to an entire server
+ ScopeServer
+)
+
+var protoScope = map[gitalypb.OperationMsg_Scope]Scope{
+ gitalypb.OperationMsg_SERVER: ScopeServer,
+ gitalypb.OperationMsg_REPOSITORY: ScopeRepository,
+ gitalypb.OperationMsg_STORAGE: ScopeStorage,
+}
+
// MethodInfo contains metadata about the RPC method. Refer to documentation
// for message type "OperationMsg" shared.proto in gitlab-org/gitaly-proto for
// more documentation.
type MethodInfo struct {
Operation OpType
+ Scope Scope
targetRepo []int
requestName string // protobuf message name for input type
requestFactory protoFactory
@@ -189,8 +210,14 @@ func parseMethodInfo(methodDesc *descriptor.MethodDescriptorProto) (MethodInfo,
return MethodInfo{}, err
}
+ scope, ok := protoScope[opMsg.GetScopeLevel()]
+ if !ok {
+ return MethodInfo{}, fmt.Errorf("encountered unknown method scope %d", opMsg.GetScopeLevel())
+ }
+
return MethodInfo{
Operation: opCode,
+ Scope: scope,
targetRepo: targetRepo,
requestName: requestName,
requestFactory: reqFactory,
diff --git a/internal/praefect/protoregistry/protoregistry_test.go b/internal/praefect/protoregistry/protoregistry_test.go
index ff8480b3b..569c304e1 100644
--- a/internal/praefect/protoregistry/protoregistry_test.go
+++ b/internal/praefect/protoregistry/protoregistry_test.go
@@ -171,7 +171,7 @@ func TestPopulatesProtoRegistry(t *testing.T) {
"SSHUploadArchive": protoregistry.OpMutator,
},
"StorageService": map[string]protoregistry.OpType{
- "ListDirectories": protoregistry.OpMutator,
+ "ListDirectories": protoregistry.OpAccessor,
"DeleteAllRepositories": protoregistry.OpMutator,
},
"WikiService": map[string]protoregistry.OpType{
@@ -208,3 +208,33 @@ func TestRequestFactory(t *testing.T) {
require.Exactly(t, &gitalypb.RepositoryExistsRequest{}, pb)
}
+
+func TestMethodInfoScope(t *testing.T) {
+ r := protoregistry.New()
+ require.NoError(t, r.RegisterFiles(protoregistry.GitalyProtoFileDescriptors...))
+
+ for _, tt := range []struct {
+ method string
+ scope protoregistry.Scope
+ }{
+ {
+ method: "/gitaly.RepositoryService/RepositoryExists",
+ scope: protoregistry.ScopeRepository,
+ },
+ {
+ method: "/gitaly.StorageService/ListDirectories",
+ scope: protoregistry.ScopeStorage,
+ },
+ {
+ method: "/gitaly.ServerService/ServerInfo",
+ scope: protoregistry.ScopeServer,
+ },
+ } {
+ t.Run(tt.method, func(t *testing.T) {
+ mInfo, err := r.LookupMethod(tt.method)
+ require.NoError(t, err)
+
+ require.Exactly(t, tt.scope, mInfo.Scope)
+ })
+ }
+}
diff --git a/proto/README.md b/proto/README.md
index 03db88256..c398d0c49 100644
--- a/proto/README.md
+++ b/proto/README.md
@@ -1,6 +1,6 @@
# Vendored copy of gitaly-proto
-Vendored from gitlab.com/gitlab-org/gitaly-proto at 617898b9c0c4c8a55c7b0abe95144109a3836270.
+Vendored from gitlab.com/gitlab-org/gitaly-proto at a1e8074ed11a176e964c505dc30d153cbe8fed4d.
Migration in progress, see
https://gitlab.com/gitlab-org/gitaly/issues/1761. Do not edit files in
diff --git a/proto/REVISION b/proto/REVISION
index f49415ca6..365cbf9b1 100644
--- a/proto/REVISION
+++ b/proto/REVISION
@@ -1 +1 @@
-v1.38.0 \ No newline at end of file
+v1.39.0 \ No newline at end of file
diff --git a/proto/VERSION b/proto/VERSION
index ebeef2f2d..5edffce6d 100644
--- a/proto/VERSION
+++ b/proto/VERSION
@@ -1 +1 @@
-1.38.0
+1.39.0
diff --git a/proto/go/gitalypb/namespace.pb.go b/proto/go/gitalypb/namespace.pb.go
index 21c711034..aa49ccb42 100644
--- a/proto/go/gitalypb/namespace.pb.go
+++ b/proto/go/gitalypb/namespace.pb.go
@@ -367,27 +367,27 @@ func init() { proto.RegisterFile("namespace.proto", fileDescriptor_ecb1e126f615f
var fileDescriptor_ecb1e126f615f5dd = []byte{
// 340 bytes of a gzipped FileDescriptorProto
- 0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0xac, 0x93, 0xcd, 0x4e, 0xc2, 0x40,
- 0x10, 0xc7, 0xd3, 0x42, 0x08, 0x8e, 0x44, 0xc8, 0x6a, 0x00, 0xd1, 0xf8, 0xd1, 0x13, 0x17, 0x5b,
- 0x3f, 0x9e, 0x40, 0x13, 0x6f, 0x46, 0x93, 0x72, 0x33, 0x26, 0x64, 0x81, 0xb1, 0x92, 0x50, 0xb6,
- 0xee, 0xae, 0x44, 0x8f, 0x3e, 0x85, 0xef, 0xea, 0xc9, 0xec, 0x6e, 0x0b, 0x6d, 0x59, 0x2e, 0xea,
- 0x6d, 0xf6, 0xff, 0x9f, 0xfe, 0x76, 0x3a, 0x33, 0x0b, 0xcd, 0x39, 0x8d, 0x51, 0x24, 0x74, 0x8c,
- 0x7e, 0xc2, 0x99, 0x64, 0xa4, 0x16, 0x4d, 0x25, 0x9d, 0x7d, 0xf4, 0x1a, 0xe2, 0x85, 0x72, 0x9c,
- 0x18, 0xd5, 0xbb, 0x83, 0xdd, 0xeb, 0xc9, 0xe4, 0x3e, 0xcb, 0x0d, 0xf1, 0xf5, 0x0d, 0x85, 0x24,
- 0xa7, 0xd0, 0x10, 0x92, 0x71, 0x1a, 0xe1, 0x50, 0x71, 0xba, 0xce, 0x89, 0xd3, 0xdf, 0x0a, 0xb7,
- 0x53, 0x4d, 0xa5, 0x13, 0x02, 0x55, 0x6d, 0xb9, 0xda, 0xd2, 0xb1, 0xf7, 0x00, 0xed, 0x10, 0x63,
- 0xb6, 0xc0, 0xff, 0x02, 0x0e, 0x15, 0x50, 0x45, 0xbf, 0x04, 0x3e, 0x73, 0x16, 0x67, 0x40, 0x15,
- 0x93, 0x1d, 0x70, 0x25, 0xeb, 0x56, 0xb4, 0xe2, 0x4a, 0xa6, 0x2a, 0x5e, 0xa2, 0x6f, 0xdf, 0xa7,
- 0x42, 0x8a, 0x3f, 0x56, 0x7c, 0x01, 0x9d, 0x35, 0xa0, 0x48, 0xd8, 0x5c, 0x20, 0x69, 0x43, 0x0d,
- 0xb5, 0xa2, 0x59, 0xf5, 0x30, 0x3d, 0x79, 0x6d, 0xd8, 0x2b, 0xce, 0xc0, 0xe4, 0x7b, 0xfb, 0xd0,
- 0x59, 0xeb, 0x66, 0xde, 0x2a, 0xf5, 0xc5, 0x58, 0x97, 0x9f, 0x15, 0x68, 0x2d, 0xd5, 0x01, 0xf2,
- 0xc5, 0x74, 0x8c, 0x64, 0x00, 0x8d, 0xfc, 0x15, 0xe4, 0xc0, 0x37, 0xdb, 0xe0, 0x5b, 0x86, 0xdf,
- 0x3b, 0xb4, 0x9b, 0xe9, 0xd5, 0xf5, 0xef, 0xaf, 0x7e, 0xb5, 0xee, 0xb4, 0x1c, 0xf2, 0x04, 0xcd,
- 0x52, 0x7d, 0xe4, 0x28, 0xfb, 0xd4, 0xbe, 0x06, 0xbd, 0xe3, 0x8d, 0xbe, 0x9d, 0x5e, 0xf8, 0xc5,
- 0x3c, 0xdd, 0xb6, 0x13, 0x79, 0xba, 0xb5, 0x37, 0x45, 0x7a, 0x69, 0x4c, 0x2b, 0xba, 0x7d, 0x21,
- 0x56, 0xf4, 0x0d, 0xf3, 0x4d, 0xe9, 0x6e, 0xcb, 0xb9, 0x39, 0x7f, 0x54, 0xb9, 0x33, 0x3a, 0xf2,
- 0xc7, 0x2c, 0x0e, 0x4c, 0x78, 0xc6, 0x78, 0x14, 0x18, 0x42, 0xa0, 0xdf, 0x5e, 0x10, 0xb1, 0xf4,
- 0x9c, 0x8c, 0x46, 0x35, 0x2d, 0x5d, 0xfd, 0x04, 0x00, 0x00, 0xff, 0xff, 0x0d, 0x5d, 0x7a, 0x6b,
+ 0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0xac, 0x93, 0xcd, 0x4e, 0x02, 0x31,
+ 0x10, 0xc7, 0x43, 0x21, 0x04, 0x47, 0x22, 0xa4, 0x1a, 0x40, 0x34, 0x7e, 0xec, 0x89, 0x8b, 0xbb,
+ 0x7e, 0x3c, 0x81, 0x26, 0xde, 0x8c, 0x26, 0xcb, 0xcd, 0x98, 0x90, 0x02, 0xe3, 0x4a, 0xc2, 0xd2,
+ 0xb5, 0xad, 0x44, 0x8f, 0x3e, 0x85, 0xef, 0xea, 0xc9, 0xb4, 0x5d, 0x60, 0x77, 0x29, 0x17, 0xf5,
+ 0x36, 0xfd, 0xff, 0x67, 0x7f, 0x9d, 0x9d, 0x99, 0x42, 0x63, 0xc6, 0x62, 0x94, 0x09, 0x1b, 0xa1,
+ 0x9f, 0x08, 0xae, 0x38, 0xad, 0x46, 0x13, 0xc5, 0xa6, 0x1f, 0xdd, 0xba, 0x7c, 0x61, 0x02, 0xc7,
+ 0x56, 0xf5, 0xee, 0x60, 0xf7, 0x7a, 0x3c, 0xbe, 0x5f, 0xe4, 0x86, 0xf8, 0xfa, 0x86, 0x52, 0xd1,
+ 0x53, 0xa8, 0x4b, 0xc5, 0x05, 0x8b, 0x70, 0xa0, 0x39, 0x9d, 0xd2, 0x49, 0xa9, 0xb7, 0x15, 0x6e,
+ 0xa7, 0x9a, 0x4e, 0xa7, 0x14, 0x2a, 0xc6, 0x22, 0xc6, 0x32, 0xb1, 0xf7, 0x00, 0xad, 0x10, 0x63,
+ 0x3e, 0xc7, 0xff, 0x02, 0x0e, 0x34, 0x50, 0x47, 0xbf, 0x04, 0x3e, 0x0b, 0x1e, 0x2f, 0x80, 0x3a,
+ 0xa6, 0x3b, 0x40, 0x14, 0xef, 0x94, 0x8d, 0x42, 0x14, 0xd7, 0x15, 0x2f, 0xd1, 0xb7, 0xef, 0x13,
+ 0xa9, 0xe4, 0x1f, 0x2b, 0xbe, 0x80, 0xf6, 0x1a, 0x50, 0x26, 0x7c, 0x26, 0x91, 0xb6, 0xa0, 0x8a,
+ 0x46, 0x31, 0xac, 0x5a, 0x98, 0x9e, 0xbc, 0x16, 0xec, 0xe5, 0x67, 0x60, 0xf3, 0xbd, 0x7d, 0x68,
+ 0xaf, 0x75, 0x33, 0x6b, 0x15, 0xfa, 0x62, 0xad, 0xcb, 0xcf, 0x32, 0x34, 0x97, 0x6a, 0x1f, 0xc5,
+ 0x7c, 0x32, 0x42, 0xda, 0x87, 0x7a, 0xf6, 0x0a, 0x7a, 0xe0, 0xdb, 0x6d, 0xf0, 0x1d, 0xc3, 0xef,
+ 0x1e, 0xba, 0xcd, 0xf4, 0xea, 0xda, 0xf7, 0x57, 0xaf, 0x52, 0x2b, 0x35, 0x09, 0x7d, 0x82, 0x46,
+ 0xa1, 0x3e, 0x7a, 0xb4, 0xf8, 0xd4, 0xbd, 0x06, 0xdd, 0xe3, 0x8d, 0xbe, 0x9b, 0x9e, 0xfb, 0xc5,
+ 0x2c, 0xdd, 0xb5, 0x13, 0x59, 0xba, 0xb3, 0x37, 0x79, 0x7a, 0x61, 0x4c, 0x2b, 0xba, 0x7b, 0x21,
+ 0x56, 0xf4, 0x0d, 0xf3, 0x4d, 0xe9, 0xa4, 0x49, 0x6e, 0xce, 0x1f, 0x75, 0xee, 0x94, 0x0d, 0xfd,
+ 0x11, 0x8f, 0x03, 0x1b, 0x9e, 0x71, 0x11, 0x05, 0x96, 0x10, 0x98, 0xb7, 0x17, 0x44, 0x3c, 0x3d,
+ 0x27, 0xc3, 0x61, 0xd5, 0x48, 0x57, 0x3f, 0x01, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x03, 0xa2, 0x6d,
0xb7, 0x03, 0x00, 0x00,
}
diff --git a/proto/go/gitalypb/storage.pb.go b/proto/go/gitalypb/storage.pb.go
index 5058414c1..5d4770406 100644
--- a/proto/go/gitalypb/storage.pb.go
+++ b/proto/go/gitalypb/storage.pb.go
@@ -190,25 +190,25 @@ func init() {
func init() { proto.RegisterFile("storage.proto", fileDescriptor_0d2c4ccf1453ffdb) }
var fileDescriptor_0d2c4ccf1453ffdb = []byte{
- // 284 bytes of a gzipped FileDescriptorProto
+ // 287 bytes of a gzipped FileDescriptorProto
0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x94, 0x51, 0xdd, 0x4a, 0xc3, 0x30,
- 0x14, 0x26, 0xfe, 0x8c, 0xed, 0xb8, 0xa9, 0x04, 0x7f, 0x46, 0x51, 0x57, 0x8b, 0x42, 0x6f, 0x6c,
- 0x87, 0x3e, 0xc1, 0x64, 0x97, 0x22, 0x98, 0xdd, 0x79, 0xa1, 0xa4, 0xdd, 0xa1, 0x0d, 0xa4, 0x4d,
- 0x4c, 0xa2, 0xe0, 0x93, 0xf8, 0x7a, 0x3e, 0x87, 0x57, 0x62, 0x53, 0x6f, 0xe6, 0xa6, 0x78, 0x97,
- 0xef, 0x4b, 0xbe, 0x9f, 0x9c, 0x03, 0x03, 0xeb, 0x94, 0xe1, 0x05, 0x26, 0xda, 0x28, 0xa7, 0x68,
- 0xa7, 0x10, 0x8e, 0xcb, 0xd7, 0xa0, 0x6f, 0x4b, 0x6e, 0x70, 0xee, 0xd9, 0xe8, 0x0e, 0x0e, 0x6e,
- 0x84, 0x75, 0x53, 0x61, 0x30, 0x77, 0xca, 0x08, 0xb4, 0x0c, 0x9f, 0x9e, 0xd1, 0x3a, 0x7a, 0x0a,
- 0xfd, 0xd6, 0xe0, 0xb1, 0xe6, 0x15, 0x0e, 0x49, 0x48, 0xe2, 0x1e, 0xdb, 0x6a, 0xb9, 0x5b, 0x5e,
- 0x21, 0xdd, 0x83, 0xcd, 0x39, 0x6a, 0x57, 0x0e, 0xd7, 0x42, 0x12, 0x0f, 0x98, 0x07, 0x51, 0x0a,
- 0x87, 0x3f, 0x2c, 0xad, 0x56, 0xb5, 0x6d, 0x04, 0x9a, 0xbb, 0xd2, 0x0e, 0x49, 0xb8, 0x1e, 0xf7,
- 0x98, 0x07, 0xd1, 0x04, 0x8e, 0xa6, 0x28, 0xd1, 0xe1, 0x44, 0x4a, 0x86, 0x5a, 0x59, 0xf1, 0xdf,
- 0x26, 0xd1, 0x08, 0x8e, 0x57, 0x58, 0xf8, 0xe4, 0xcb, 0x77, 0x02, 0xdb, 0x33, 0x2f, 0x98, 0xa1,
- 0x79, 0x11, 0x39, 0xd2, 0x07, 0xd8, 0x59, 0xe8, 0x49, 0x4f, 0x12, 0x3f, 0xa4, 0x64, 0xf9, 0x4c,
- 0x82, 0xd1, 0xca, 0x7b, 0x1f, 0x13, 0x75, 0x3f, 0xde, 0xe2, 0x8d, 0x2e, 0xd9, 0x25, 0x63, 0x42,
- 0x6b, 0xd8, 0x5f, 0xda, 0x89, 0x9e, 0x7d, 0xbb, 0xfc, 0xf6, 0xeb, 0xe0, 0xfc, 0x8f, 0x57, 0x8b,
- 0x89, 0xd7, 0xe3, 0xfb, 0x2f, 0x85, 0xe4, 0x59, 0x92, 0xab, 0x2a, 0xf5, 0xc7, 0x0b, 0x65, 0x8a,
- 0xd4, 0xfb, 0xa4, 0xcd, 0xc2, 0xd3, 0x42, 0xb5, 0x58, 0x67, 0x59, 0xa7, 0xa1, 0xae, 0x3e, 0x03,
- 0x00, 0x00, 0xff, 0xff, 0x8f, 0xf0, 0xce, 0x16, 0x2a, 0x02, 0x00, 0x00,
+ 0x14, 0x26, 0x55, 0xc7, 0x76, 0xdc, 0x74, 0x04, 0x7f, 0x46, 0x51, 0x57, 0x8b, 0x42, 0x6f, 0x6c,
+ 0x87, 0x3e, 0xc1, 0x64, 0x97, 0x22, 0xd8, 0xdd, 0x79, 0xa1, 0xa4, 0xdd, 0xa1, 0x0d, 0xa4, 0x4d,
+ 0x4c, 0xa2, 0xe0, 0x93, 0xf8, 0x7a, 0x3e, 0x87, 0x57, 0x62, 0x53, 0x2f, 0xd4, 0x4d, 0xf1, 0x2e,
+ 0xdf, 0x97, 0x7c, 0x3f, 0x39, 0x07, 0x06, 0xc6, 0x4a, 0xcd, 0x0a, 0x8c, 0x95, 0x96, 0x56, 0xd2,
+ 0x4e, 0xc1, 0x2d, 0x13, 0xcf, 0x7e, 0xdf, 0x94, 0x4c, 0xe3, 0xc2, 0xb1, 0xe1, 0x0d, 0xec, 0x5d,
+ 0x71, 0x63, 0x67, 0x5c, 0x63, 0x6e, 0xa5, 0xe6, 0x68, 0x52, 0x7c, 0x78, 0x44, 0x63, 0xe9, 0x31,
+ 0xf4, 0x5b, 0x83, 0xfb, 0x9a, 0x55, 0x38, 0x22, 0x01, 0x89, 0x7a, 0xe9, 0x66, 0xcb, 0x5d, 0xb3,
+ 0x0a, 0xe9, 0x0e, 0x6c, 0x2c, 0x50, 0xd9, 0x72, 0xe4, 0x05, 0x24, 0x1a, 0xa4, 0x0e, 0x84, 0x09,
+ 0xec, 0xff, 0xb0, 0x34, 0x4a, 0xd6, 0xa6, 0x11, 0x28, 0x66, 0x4b, 0x33, 0x22, 0xc1, 0x5a, 0xd4,
+ 0x4b, 0x1d, 0x08, 0xa7, 0x70, 0x30, 0x43, 0x81, 0x16, 0xa7, 0x42, 0xa4, 0xa8, 0xa4, 0xe1, 0xff,
+ 0x6d, 0x12, 0x8e, 0xe1, 0x70, 0x85, 0x85, 0x4b, 0x3e, 0x7f, 0x25, 0xb0, 0x35, 0x77, 0x82, 0x39,
+ 0xea, 0x27, 0x9e, 0x23, 0xbd, 0x83, 0xed, 0x6f, 0x3d, 0xe9, 0x51, 0xec, 0x86, 0x14, 0x2f, 0x9f,
+ 0x89, 0x3f, 0x5e, 0x79, 0xef, 0x62, 0xc2, 0xee, 0xdb, 0x4b, 0xb4, 0xde, 0xf5, 0x86, 0xde, 0x84,
+ 0xd0, 0x1a, 0x76, 0x97, 0x76, 0xa2, 0x27, 0x9f, 0x2e, 0xbf, 0xfd, 0xda, 0x3f, 0xfd, 0xe3, 0xd5,
+ 0x97, 0x44, 0x32, 0xf4, 0x2e, 0x27, 0xb7, 0x1f, 0x0a, 0xc1, 0xb2, 0x38, 0x97, 0x55, 0xe2, 0x8e,
+ 0x67, 0x52, 0x17, 0x89, 0xf3, 0x49, 0x9a, 0x85, 0x27, 0x85, 0x6c, 0xb1, 0xca, 0xb2, 0x4e, 0x43,
+ 0x5d, 0xbc, 0x07, 0x00, 0x00, 0xff, 0xff, 0x66, 0xad, 0x6a, 0x34, 0x2a, 0x02, 0x00, 0x00,
}
// Reference imports to suppress errors if they are not otherwise used.
diff --git a/proto/namespace.proto b/proto/namespace.proto
index 4b5ba45d7..54ce1ceaa 100644
--- a/proto/namespace.proto
+++ b/proto/namespace.proto
@@ -10,25 +10,25 @@ service NamespaceService {
rpc AddNamespace(AddNamespaceRequest) returns (AddNamespaceResponse) {
option (op_type) = {
op: MUTATOR
- scope_level: SERVER,
+ scope_level: STORAGE,
};
}
rpc RemoveNamespace(RemoveNamespaceRequest) returns (RemoveNamespaceResponse) {
option (op_type) = {
op: MUTATOR
- scope_level: SERVER,
+ scope_level: STORAGE,
};
}
rpc RenameNamespace(RenameNamespaceRequest) returns (RenameNamespaceResponse) {
option (op_type) = {
op: MUTATOR
- scope_level: SERVER,
+ scope_level: STORAGE,
};
}
rpc NamespaceExists(NamespaceExistsRequest) returns (NamespaceExistsResponse) {
option (op_type) = {
op: ACCESSOR
- scope_level: SERVER,
+ scope_level: STORAGE,
};
}
}
diff --git a/proto/storage.proto b/proto/storage.proto
index 903c8137c..74d753267 100644
--- a/proto/storage.proto
+++ b/proto/storage.proto
@@ -9,14 +9,14 @@ import "shared.proto";
service StorageService {
rpc ListDirectories(ListDirectoriesRequest) returns (stream ListDirectoriesResponse) {
option (op_type) = {
- op: MUTATOR
- scope_level: SERVER,
+ op: ACCESSOR,
+ scope_level: STORAGE,
};
}
rpc DeleteAllRepositories(DeleteAllRepositoriesRequest) returns (DeleteAllRepositoriesResponse) {
option (op_type) = {
- op: MUTATOR
- scope_level: SERVER,
+ op: MUTATOR,
+ scope_level: STORAGE,
};
}
}
diff --git a/ruby/proto/gitaly/shared_pb.rb b/ruby/proto/gitaly/shared_pb.rb
index 8fa21f0bf..9b4294067 100644
--- a/ruby/proto/gitaly/shared_pb.rb
+++ b/ruby/proto/gitaly/shared_pb.rb
@@ -18,6 +18,7 @@ Google::Protobuf::DescriptorPool.generated_pool.build do
add_enum "gitaly.OperationMsg.Scope" do
value :REPOSITORY, 0
value :SERVER, 1
+ value :STORAGE, 2
end
add_message "gitaly.Repository" do
optional :storage_name, :string, 2
diff --git a/proto/go/gitalypb/shared.pb.go b/proto/go/gitalypb/shared.pb.go
index 711b5b28d..05bd72e83 100644
--- a/proto/go/gitalypb/shared.pb.go
+++ b/proto/go/gitalypb/shared.pb.go
@@ -89,16 +89,19 @@ type OperationMsg_Scope int32
const (
OperationMsg_REPOSITORY OperationMsg_Scope = 0
OperationMsg_SERVER OperationMsg_Scope = 1
+ OperationMsg_STORAGE OperationMsg_Scope = 2
)
var OperationMsg_Scope_name = map[int32]string{
0: "REPOSITORY",
1: "SERVER",
+ 2: "STORAGE",
}
var OperationMsg_Scope_value = map[string]int32{
"REPOSITORY": 0,
"SERVER": 1,
+ "STORAGE": 2,
}
func (x OperationMsg_Scope) String() string {
@@ -111,9 +114,10 @@ func (OperationMsg_Scope) EnumDescriptor() ([]byte, []int) {
type OperationMsg struct {
Op OperationMsg_Operation `protobuf:"varint,1,opt,name=op,proto3,enum=gitaly.OperationMsg_Operation" json:"op,omitempty"`
// Scope level indicates how a mutating RPC affects Gitaly:
// - REPOSITORY: mutation is scoped to only a single repo
// - SERVER: mutation affects the entire server and potentially all repos
ScopeLevel OperationMsg_Scope `protobuf:"varint,2,opt,name=scope_level,json=scopeLevel,proto3,enum=gitaly.OperationMsg_Scope" json:"scope_level,omitempty"`
// If this operation modifies a repository, this field will
// specify the location of the Repository field within the
@@ -716,61 +720,62 @@ func init() {
func init() { proto.RegisterFile("shared.proto", fileDescriptor_d8a4e87e678c5ced) }
var fileDescriptor_d8a4e87e678c5ced = []byte{
- // 890 bytes of a gzipped FileDescriptorProto
+ // 899 bytes of a gzipped FileDescriptorProto
0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x8c, 0x55, 0xdd, 0x6e, 0xe3, 0x44,
- 0x14, 0x5e, 0x3b, 0xce, 0xdf, 0x89, 0x5b, 0xcc, 0x50, 0x84, 0x55, 0xb4, 0xbb, 0xc1, 0x2b, 0xa1,
- 0x0a, 0x41, 0xba, 0xea, 0x4a, 0x7b, 0x01, 0x37, 0x24, 0x25, 0x54, 0x5d, 0x36, 0x75, 0x35, 0x71,
- 0x41, 0x70, 0x63, 0x4d, 0xe2, 0xe9, 0x64, 0x90, 0x9d, 0xb1, 0xc6, 0x93, 0x8a, 0xee, 0x25, 0xf7,
- 0xbc, 0x0a, 0x4f, 0xc2, 0x7b, 0xf0, 0x18, 0xa0, 0x99, 0xb1, 0xd3, 0x6c, 0xb7, 0xa0, 0xbd, 0x9b,
- 0x73, 0xce, 0x77, 0xfe, 0xcf, 0x67, 0x83, 0x5f, 0xad, 0x88, 0xa4, 0xd9, 0xa8, 0x94, 0x42, 0x09,
- 0xd4, 0x61, 0x5c, 0x91, 0xfc, 0xf6, 0xf0, 0x29, 0x13, 0x82, 0xe5, 0xf4, 0xd8, 0x68, 0x17, 0x9b,
- 0xeb, 0x63, 0xc5, 0x0b, 0x5a, 0x29, 0x52, 0x94, 0x16, 0x78, 0x38, 0xbc, 0x0f, 0xc8, 0x68, 0xb5,
- 0x94, 0xbc, 0x54, 0x42, 0x5a, 0x44, 0xf4, 0x87, 0x0b, 0x7e, 0x5c, 0x52, 0x49, 0x14, 0x17, 0xeb,
- 0x59, 0xc5, 0xd0, 0x08, 0x5c, 0x51, 0x86, 0xce, 0xd0, 0x39, 0xda, 0x3f, 0x79, 0x32, 0xb2, 0x89,
- 0x46, 0xbb, 0x88, 0x3b, 0x01, 0xbb, 0xa2, 0x44, 0xdf, 0xc0, 0xa0, 0x5a, 0x8a, 0x92, 0xa6, 0x39,
- 0xbd, 0xa1, 0x79, 0xe8, 0x1a, 0xc7, 0xc3, 0x07, 0x1d, 0xe7, 0x1a, 0x87, 0xc1, 0xc0, 0x5f, 0x6b,
- 0x34, 0x7a, 0x09, 0x9f, 0x28, 0x22, 0x19, 0x55, 0xa9, 0xa4, 0xa5, 0xa8, 0xb8, 0x12, 0xf2, 0x36,
- 0xbd, 0xe6, 0x34, 0xcf, 0xc2, 0xd6, 0xd0, 0x39, 0xea, 0xe3, 0x8f, 0xad, 0x19, 0x6f, 0xad, 0xdf,
- 0x6b, 0x63, 0xf4, 0x02, 0xfa, 0xdb, 0xc8, 0x68, 0x00, 0xdd, 0xab, 0x8b, 0x1f, 0x2e, 0xe2, 0x9f,
- 0x2e, 0x82, 0x47, 0x5a, 0x98, 0x5d, 0x25, 0xe3, 0x24, 0xc6, 0x81, 0x83, 0x7c, 0xe8, 0x8d, 0x4f,
- 0x4f, 0xa7, 0xf3, 0x79, 0x8c, 0x03, 0x37, 0x7a, 0x06, 0x6d, 0x53, 0x01, 0xda, 0x07, 0xc0, 0xd3,
- 0xcb, 0x78, 0x7e, 0x9e, 0xc4, 0xf8, 0xe7, 0xe0, 0x11, 0x02, 0xe8, 0xcc, 0xa7, 0xf8, 0xc7, 0x29,
- 0x0e, 0x9c, 0xe8, 0x4f, 0x17, 0xe0, 0x2e, 0x1b, 0xfa, 0x0c, 0xfc, 0x4a, 0x09, 0x49, 0x18, 0x4d,
- 0xd7, 0xa4, 0xa0, 0xa6, 0xbd, 0x3e, 0x1e, 0xd4, 0xba, 0x0b, 0x52, 0x50, 0xf4, 0x0c, 0xf6, 0x24,
- 0xcd, 0x89, 0xe2, 0x37, 0x34, 0x2d, 0x89, 0x5a, 0xd5, 0x95, 0xfb, 0x8d, 0xf2, 0x92, 0xa8, 0x15,
- 0x7a, 0x0e, 0x07, 0x8c, 0xab, 0x54, 0x2c, 0x7e, 0xa5, 0x4b, 0x95, 0x66, 0x5c, 0xd2, 0xa5, 0x8e,
- 0x1f, 0x7a, 0x06, 0x8b, 0x18, 0x57, 0xb1, 0x31, 0x7d, 0xd7, 0x58, 0xd0, 0x19, 0x0c, 0xb5, 0x07,
- 0xc9, 0x15, 0x95, 0x6b, 0xa2, 0xe8, 0x7d, 0x5f, 0x4e, 0xab, 0xb0, 0x3d, 0x6c, 0x1d, 0xf5, 0xf1,
- 0x63, 0xc6, 0xd5, 0xb8, 0x81, 0xbd, 0x1d, 0x86, 0xd3, 0x4a, 0xd7, 0xc7, 0xf2, 0x9d, 0xf9, 0x86,
- 0x1d, 0x5b, 0x1f, 0xcb, 0x77, 0xfa, 0xfc, 0x1c, 0x3e, 0x60, 0x79, 0x5a, 0x4a, 0x61, 0x72, 0x98,
- 0x36, 0x7a, 0x06, 0xb6, 0xc7, 0xf2, 0x4b, 0xab, 0xd5, 0x7d, 0xbc, 0xf2, 0x7a, 0x4e, 0xe0, 0xbe,
- 0xf2, 0x7a, 0xdd, 0xa0, 0x87, 0x3d, 0x0d, 0x8b, 0xfe, 0x76, 0xa0, 0x7f, 0xc6, 0xd5, 0xa9, 0x28,
- 0x0a, 0xae, 0xd0, 0x3e, 0xb8, 0x3c, 0x33, 0xd7, 0xd3, 0xc7, 0x2e, 0xcf, 0x50, 0x08, 0xdd, 0x6a,
- 0x63, 0x4a, 0x32, 0xa3, 0xf3, 0x71, 0x23, 0x22, 0x04, 0xde, 0x42, 0x64, 0xb7, 0x66, 0x5a, 0x3e,
- 0x36, 0x6f, 0xf4, 0x25, 0x74, 0xc8, 0x46, 0xad, 0x84, 0x34, 0x73, 0x19, 0x9c, 0x1c, 0x34, 0x67,
- 0x64, 0xa3, 0x8f, 0x8d, 0x0d, 0xd7, 0x18, 0x74, 0x02, 0xfd, 0xa5, 0xd1, 0x2b, 0x2a, 0xc3, 0xf6,
- 0xff, 0x38, 0xdc, 0xc1, 0xd0, 0x63, 0x80, 0x92, 0x48, 0xba, 0x56, 0x29, 0xcf, 0xaa, 0xb0, 0x63,
- 0xe6, 0xd7, 0xb7, 0x9a, 0xf3, 0xac, 0x42, 0x9f, 0x42, 0x5f, 0x17, 0x92, 0x56, 0xfc, 0x0d, 0x0d,
- 0xbb, 0x43, 0xe7, 0xa8, 0x85, 0x7b, 0x5a, 0x31, 0xe7, 0x6f, 0x68, 0xb4, 0x02, 0x7f, 0x37, 0xac,
- 0xee, 0xc0, 0xdc, 0x84, 0x63, 0x3b, 0xd0, 0x6f, 0x74, 0x00, 0x6d, 0x5a, 0x10, 0x9e, 0xd7, 0xdd,
- 0x5a, 0x01, 0x8d, 0xc0, 0xcb, 0x88, 0xa2, 0xa6, 0xd7, 0x81, 0x26, 0x87, 0x61, 0xe5, 0xa8, 0x61,
- 0xe5, 0x28, 0x69, 0x68, 0x8b, 0x0d, 0x2e, 0x8a, 0x00, 0xa6, 0xbf, 0x71, 0x35, 0x57, 0x44, 0x6d,
- 0x2a, 0x1d, 0xf3, 0x86, 0xe4, 0x1b, 0x9b, 0xa8, 0x8d, 0xad, 0x10, 0x25, 0xd0, 0x99, 0x48, 0xb2,
- 0x5e, 0xae, 0x1e, 0xac, 0xe3, 0x25, 0xec, 0xd5, 0xc4, 0xb2, 0xbd, 0x9b, 0x7a, 0x06, 0x27, 0x1f,
- 0x36, 0xf3, 0xd9, 0x6e, 0x0c, 0xfb, 0x16, 0x67, 0xa5, 0xe8, 0x2f, 0x07, 0x5a, 0x09, 0x61, 0x0f,
- 0xc6, 0xb4, 0xbb, 0x75, 0xb7, 0xbb, 0x7d, 0x27, 0x47, 0xeb, 0xbd, 0x72, 0xe8, 0x9b, 0x28, 0x68,
- 0x55, 0x11, 0x46, 0xcd, 0x9a, 0x7d, 0xdc, 0x88, 0x9a, 0x6d, 0xf5, 0xd3, 0x6e, 0xa0, 0x6d, 0x36,
- 0x30, 0xa8, 0x75, 0x7a, 0x09, 0xfa, 0x44, 0x14, 0x61, 0x8c, 0x4a, 0x73, 0xc6, 0xff, 0x79, 0x22,
- 0x16, 0x13, 0x5d, 0x83, 0x77, 0x55, 0x51, 0x89, 0x3e, 0x82, 0x36, 0xcb, 0xd3, 0xed, 0x65, 0x7a,
- 0x2c, 0x3f, 0xcf, 0xb6, 0x3d, 0xba, 0x0f, 0xed, 0xaf, 0xb5, 0xbb, 0xbf, 0xa7, 0x30, 0x60, 0x79,
- 0xba, 0xa9, 0x34, 0xc5, 0x0a, 0x5a, 0x93, 0x16, 0x58, 0x7e, 0x55, 0x6b, 0xa2, 0x6f, 0x01, 0x2c,
- 0xf1, 0x2e, 0x85, 0xc8, 0xd1, 0x09, 0xc0, 0x0e, 0xdd, 0x1c, 0x53, 0x27, 0x6a, 0xea, 0xbc, 0x23,
- 0x1d, 0xde, 0x41, 0x7d, 0x31, 0x69, 0x22, 0x24, 0xb7, 0x25, 0x7d, 0xfb, 0x93, 0x06, 0xd0, 0x39,
- 0x8d, 0x67, 0xb3, 0xf3, 0x24, 0x70, 0x50, 0x0f, 0xbc, 0xc9, 0xeb, 0x78, 0x12, 0xb8, 0xfa, 0x95,
- 0xe0, 0xe9, 0x34, 0x68, 0xa1, 0x2e, 0xb4, 0x92, 0xf1, 0x59, 0xe0, 0x7d, 0x1d, 0x43, 0x57, 0x94,
- 0xa9, 0xd2, 0x01, 0x9e, 0xbc, 0x73, 0x63, 0x33, 0xaa, 0x56, 0x22, 0x8b, 0x4b, 0xfd, 0xc9, 0xac,
- 0xc2, 0x7f, 0x7e, 0xbf, 0x47, 0x98, 0xdd, 0x0f, 0x35, 0xee, 0x88, 0x52, 0x97, 0x31, 0x79, 0xfe,
- 0x8b, 0x36, 0xe7, 0x64, 0x31, 0x5a, 0x8a, 0xe2, 0xd8, 0x3e, 0xbf, 0x12, 0x92, 0x1d, 0x5b, 0x27,
- 0xfb, 0x5b, 0x39, 0x66, 0xa2, 0x96, 0xcb, 0xc5, 0xa2, 0x63, 0x54, 0x2f, 0xfe, 0x0d, 0x00, 0x00,
- 0xff, 0xff, 0xbc, 0x8f, 0x1f, 0xb5, 0xb0, 0x06, 0x00, 0x00,
+ 0x14, 0x5e, 0x3b, 0xce, 0xdf, 0x89, 0x5b, 0xcc, 0x50, 0x84, 0x55, 0xb4, 0xbb, 0xc1, 0x48, 0xa8,
+ 0x42, 0x90, 0x56, 0x5d, 0x69, 0x2f, 0xe0, 0x86, 0xa4, 0x84, 0xaa, 0xcb, 0xa6, 0xae, 0x26, 0x2e,
+ 0x08, 0x6e, 0xac, 0x49, 0x3c, 0x9d, 0x0c, 0xb2, 0x33, 0xd6, 0x78, 0x52, 0xd1, 0xbd, 0xe4, 0x31,
+ 0x78, 0x08, 0x9e, 0x84, 0xf7, 0xe0, 0x31, 0x40, 0x33, 0x63, 0xa7, 0xd9, 0x6e, 0x41, 0xdc, 0xcd,
+ 0x39, 0xe7, 0x3b, 0xff, 0xe7, 0xb3, 0xc1, 0xaf, 0x56, 0x44, 0xd2, 0x6c, 0x54, 0x4a, 0xa1, 0x04,
+ 0xea, 0x30, 0xae, 0x48, 0x7e, 0x77, 0xf8, 0x9c, 0x09, 0xc1, 0x72, 0x7a, 0x6c, 0xb4, 0x8b, 0xcd,
+ 0xcd, 0xb1, 0xe2, 0x05, 0xad, 0x14, 0x29, 0x4a, 0x0b, 0x3c, 0x1c, 0x3e, 0x04, 0x64, 0xb4, 0x5a,
+ 0x4a, 0x5e, 0x2a, 0x21, 0x2d, 0x22, 0xfa, 0xdd, 0x05, 0x3f, 0x2e, 0xa9, 0x24, 0x8a, 0x8b, 0xf5,
+ 0xac, 0x62, 0x68, 0x04, 0xae, 0x28, 0x43, 0x67, 0xe8, 0x1c, 0xed, 0x9f, 0x3e, 0x1b, 0xd9, 0x44,
+ 0xa3, 0x5d, 0xc4, 0xbd, 0x80, 0x5d, 0x51, 0xa2, 0xaf, 0x61, 0x50, 0x2d, 0x45, 0x49, 0xd3, 0x9c,
+ 0xde, 0xd2, 0x3c, 0x74, 0x8d, 0xe3, 0xe1, 0xa3, 0x8e, 0x73, 0x8d, 0xc3, 0x60, 0xe0, 0xaf, 0x35,
+ 0x1a, 0xbd, 0x84, 0x8f, 0x14, 0x91, 0x8c, 0xaa, 0x54, 0xd2, 0x52, 0x54, 0x5c, 0x09, 0x79, 0x97,
+ 0xde, 0x70, 0x9a, 0x67, 0x61, 0x6b, 0xe8, 0x1c, 0xf5, 0xf1, 0x87, 0xd6, 0x8c, 0xb7, 0xd6, 0xef,
+ 0xb4, 0x31, 0x7a, 0x01, 0xfd, 0x6d, 0x64, 0x34, 0x80, 0xee, 0xf5, 0xe5, 0xf7, 0x97, 0xf1, 0x8f,
+ 0x97, 0xc1, 0x13, 0x2d, 0xcc, 0xae, 0x93, 0x71, 0x12, 0xe3, 0xc0, 0x41, 0x3e, 0xf4, 0xc6, 0x67,
+ 0x67, 0xd3, 0xf9, 0x3c, 0xc6, 0x81, 0x1b, 0x9d, 0x40, 0xdb, 0x54, 0x80, 0xf6, 0x01, 0xf0, 0xf4,
+ 0x2a, 0x9e, 0x5f, 0x24, 0x31, 0xfe, 0x29, 0x78, 0x82, 0x00, 0x3a, 0xf3, 0x29, 0xfe, 0x61, 0xaa,
+ 0x5d, 0x06, 0xd0, 0x9d, 0x27, 0x31, 0x1e, 0x9f, 0x4f, 0x03, 0x37, 0xfa, 0xc3, 0x05, 0xb8, 0x4f,
+ 0x8d, 0x3e, 0x01, 0xbf, 0x52, 0x42, 0x12, 0x46, 0xd3, 0x35, 0x29, 0xa8, 0xe9, 0xb5, 0x8f, 0x07,
+ 0xb5, 0xee, 0x92, 0x14, 0x14, 0x7d, 0x0a, 0x7b, 0x92, 0xe6, 0x44, 0xf1, 0x5b, 0x9a, 0x96, 0x44,
+ 0xad, 0xea, 0x36, 0xfc, 0x46, 0x79, 0x45, 0xd4, 0x0a, 0x9d, 0xc0, 0x01, 0xe3, 0x2a, 0x15, 0x8b,
+ 0x5f, 0xe8, 0x52, 0xa5, 0x19, 0x97, 0x74, 0xa9, 0xe3, 0x87, 0x9e, 0xc1, 0x22, 0xc6, 0x55, 0x6c,
+ 0x4c, 0xdf, 0x36, 0x16, 0x74, 0x0e, 0x43, 0xed, 0x41, 0x72, 0x45, 0xe5, 0x9a, 0x28, 0xfa, 0xd0,
+ 0x97, 0xd3, 0x2a, 0x6c, 0x0f, 0x5b, 0x47, 0x7d, 0xfc, 0x94, 0x71, 0x35, 0x6e, 0x60, 0x6f, 0x87,
+ 0xe1, 0xb4, 0xd2, 0xf5, 0xb1, 0x7c, 0x67, 0xd8, 0x61, 0xc7, 0xd6, 0xc7, 0xf2, 0x9d, 0x3e, 0x3f,
+ 0x83, 0xf7, 0x58, 0x9e, 0x96, 0x52, 0x98, 0x1c, 0xa6, 0x8d, 0x9e, 0x81, 0xed, 0xb1, 0xfc, 0xca,
+ 0x6a, 0x75, 0x1f, 0xaf, 0xbc, 0x9e, 0x13, 0xb8, 0xaf, 0xbc, 0x5e, 0x37, 0xe8, 0x61, 0x4f, 0xc3,
+ 0xa2, 0xbf, 0x1c, 0xe8, 0x9f, 0x73, 0x75, 0x26, 0x8a, 0x82, 0x2b, 0xb4, 0x0f, 0x2e, 0xcf, 0xcc,
+ 0x29, 0xf5, 0xb1, 0xcb, 0x33, 0x14, 0x42, 0xb7, 0xda, 0x98, 0x92, 0xcc, 0xe8, 0x7c, 0xdc, 0x88,
+ 0x08, 0x81, 0xb7, 0x10, 0xd9, 0x9d, 0x99, 0x96, 0x8f, 0xcd, 0x1b, 0x7d, 0x01, 0x1d, 0xb2, 0x51,
+ 0x2b, 0x21, 0xcd, 0x5c, 0x06, 0xa7, 0x07, 0xcd, 0x4d, 0xd9, 0xe8, 0x63, 0x63, 0xc3, 0x35, 0x06,
+ 0x9d, 0x42, 0x7f, 0x69, 0xf4, 0x8a, 0xca, 0xb0, 0xfd, 0x1f, 0x0e, 0xf7, 0x30, 0xf4, 0x14, 0xa0,
+ 0x24, 0x92, 0xae, 0x55, 0xca, 0xb3, 0x2a, 0xec, 0x98, 0xf9, 0xf5, 0xad, 0xe6, 0x22, 0xab, 0xd0,
+ 0xc7, 0xd0, 0xd7, 0x85, 0xa4, 0x15, 0x7f, 0x43, 0xc3, 0xee, 0xd0, 0x39, 0x6a, 0xe1, 0x9e, 0x56,
+ 0xcc, 0xf9, 0x1b, 0x1a, 0xad, 0xc0, 0xdf, 0x0d, 0xab, 0x3b, 0x30, 0x37, 0xe1, 0xd8, 0x0e, 0xf4,
+ 0x1b, 0x1d, 0x40, 0x9b, 0x16, 0x84, 0xe7, 0x75, 0xb7, 0x56, 0x40, 0x23, 0xf0, 0x32, 0xa2, 0xa8,
+ 0xe9, 0x75, 0xa0, 0x99, 0x62, 0x28, 0x3a, 0x6a, 0x28, 0x3a, 0x4a, 0x1a, 0x0e, 0x63, 0x83, 0x8b,
+ 0x22, 0x80, 0xe9, 0xaf, 0x5c, 0xcd, 0x15, 0x51, 0x9b, 0x4a, 0xc7, 0xbc, 0x25, 0xf9, 0xc6, 0x26,
+ 0x6a, 0x63, 0x2b, 0x44, 0x09, 0x74, 0x26, 0x92, 0xac, 0x97, 0xab, 0x47, 0xeb, 0x78, 0x09, 0x7b,
+ 0x35, 0xcb, 0x6c, 0xef, 0xa6, 0x9e, 0xc1, 0xe9, 0xfb, 0xcd, 0x7c, 0xb6, 0x1b, 0xc3, 0xbe, 0xc5,
+ 0x59, 0x29, 0xfa, 0xd3, 0x81, 0x56, 0x42, 0xd8, 0xa3, 0x31, 0xed, 0x6e, 0xdd, 0xed, 0x6e, 0xdf,
+ 0xc9, 0xd1, 0xfa, 0x5f, 0x39, 0xf4, 0x4d, 0x14, 0xb4, 0xaa, 0x08, 0xa3, 0x66, 0xcd, 0x3e, 0x6e,
+ 0x44, 0xcd, 0xb6, 0xfa, 0x69, 0x37, 0xd0, 0x36, 0x1b, 0x18, 0xd4, 0x3a, 0xbd, 0x04, 0x7d, 0x22,
+ 0x8a, 0x30, 0x46, 0xa5, 0x39, 0xe3, 0x7f, 0x3d, 0x11, 0x8b, 0x89, 0x6e, 0xc0, 0xbb, 0xae, 0xa8,
+ 0x44, 0x1f, 0x40, 0x9b, 0xe5, 0xe9, 0xf6, 0x32, 0x3d, 0x96, 0x5f, 0x64, 0xdb, 0x1e, 0xdd, 0xc7,
+ 0xf6, 0xd7, 0xda, 0xdd, 0xdf, 0x73, 0x18, 0xb0, 0x3c, 0xdd, 0x54, 0x9a, 0x62, 0x05, 0xad, 0x49,
+ 0x0b, 0x2c, 0xbf, 0xae, 0x35, 0xd1, 0x37, 0x00, 0x96, 0x78, 0x57, 0x42, 0xe4, 0xe8, 0x14, 0x60,
+ 0x87, 0x6e, 0x8e, 0xa9, 0x13, 0x35, 0x75, 0xde, 0x93, 0x0e, 0xef, 0xa0, 0x3e, 0x9f, 0x34, 0x11,
+ 0x92, 0xbb, 0x92, 0xbe, 0xfd, 0x7d, 0x03, 0xe8, 0x9c, 0xc5, 0xb3, 0xd9, 0x45, 0x12, 0x38, 0xa8,
+ 0x07, 0xde, 0xe4, 0x75, 0x3c, 0x09, 0x5c, 0xfd, 0x4a, 0xf0, 0x74, 0x1a, 0xb4, 0x50, 0x17, 0x5a,
+ 0xc9, 0xf8, 0x3c, 0xf0, 0xbe, 0x8a, 0xa1, 0x2b, 0xca, 0x54, 0xe9, 0x00, 0xcf, 0xde, 0xb9, 0xb1,
+ 0x19, 0x55, 0x2b, 0x91, 0xc5, 0xa5, 0xfe, 0x7e, 0x56, 0xe1, 0xdf, 0xbf, 0x3d, 0x20, 0xcc, 0xee,
+ 0x57, 0x1b, 0x77, 0x44, 0xa9, 0xcb, 0x98, 0x9c, 0xfc, 0xac, 0xcd, 0x39, 0x59, 0x8c, 0x96, 0xa2,
+ 0x38, 0xb6, 0xcf, 0x2f, 0x85, 0x64, 0xc7, 0xd6, 0xc9, 0xfe, 0x63, 0x8e, 0x99, 0xa8, 0xe5, 0x72,
+ 0xb1, 0xe8, 0x18, 0xd5, 0x8b, 0x7f, 0x02, 0x00, 0x00, 0xff, 0xff, 0x2f, 0xad, 0xe3, 0x2d, 0xbd,
+ 0x06, 0x00, 0x00,
}
@@ -111,9 +114,10 @@ func (OperationMsg_Scope) EnumDescriptor() ([]byte, []int) {
type OperationMsg struct {
Op OperationMsg_Operation `protobuf:"varint,1,opt,name=op,proto3,enum=gitaly.OperationMsg_Operation" json:"op,omitempty"`
- // Scope level indicates how a mutating RPC affects Gitaly:
- // - REPOSITORY: mutation is scoped to only a single repo
- // - SERVER: mutation affects the entire server and potentially all repos
+ // Scope level indicates what level an RPC interacts with a server:
+ // - REPOSITORY: scoped to only a single repo
+ // - SERVER: affects the entire server and potentially all repos
+ // - STORAGE: scoped to a specific storage location and all repos within
ScopeLevel OperationMsg_Scope `protobuf:"varint,2,opt,name=scope_level,json=scopeLevel,proto3,enum=gitaly.OperationMsg_Scope" json:"scope_level,omitempty"`
// If this operation modifies a repository, this field will
diff --git a/proto/shared.proto b/proto/shared.proto
index c252349c9..b4c3dbac4 100644
--- a/proto/shared.proto
+++ b/proto/shared.proto
@@ -19,11 +19,13 @@ message OperationMsg {
enum Scope {
REPOSITORY = 0;
SERVER = 1;
+ STORAGE = 2;
}
// Scope level indicates how a mutating RPC affects Gitaly:
// - REPOSITORY: mutation is scoped to only a single repo
// - SERVER: mutation affects the entire server and potentially all repos
Scope scope_level = 2;
// If this operation modifies a repository, this field will
@@ -19,11 +19,13 @@ message OperationMsg {
}
- // Scope level indicates how a mutating RPC affects Gitaly:
- // - REPOSITORY: mutation is scoped to only a single repo
- // - SERVER: mutation affects the entire server and potentially all repos
+ // Scope level indicates what level an RPC interacts with a server:
+ // - REPOSITORY: scoped to only a single repo
+ // - SERVER: affects the entire server and potentially all repos
+ // - STORAGE: scoped to a specific storage location and all repos within
Scope scope_level = 2;
// If this operation modifies a repository, this field will